CommandRegistry class

Registry for command types and their deserialization functions

Constructors

CommandRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clear() → void
Clear all registered command types (useful for testing)
fromCbor(List<int> bytes) Command
Create a command from CBOR bytes using the registry
fromMap(Map<String, dynamic> map) Command
Create a command from a map using the registry
getRegisteredTypes() List<String>
Get all registered command types
register<T extends Command>(String typeName, T fromMap(Map<String, dynamic>)) → void
Register a command type with its deserialization function