ProjectionInfo class

Information about a projection's current state

Constructors

ProjectionInfo({required String projectionId, required ProjectionStatus status, required int lastProcessedSequence, required DateTime lastUpdated, required int eventsProcessed, Duration? averageProcessingTime, String? lastError})
const

Properties

averageProcessingTime Duration?
final
eventsProcessed int
final
hashCode int
The hash code for this object.
no setterinherited
lastError String?
final
lastProcessedSequence int
final
lastUpdated DateTime
final
projectionId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ProjectionStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited