CborSerializer class
Utility class for CBOR serialization and deserialization
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
compress(
List< int> bytes) → List<int> - Compress CBOR data (simple implementation)
-
decompress(
List< int> bytes) → List<int> - Decompress CBOR data
-
deserializeEvent(
List< int> bytes, String eventType) → Event - Deserialize an event from CBOR bytes
-
deserializeMetadata(
List< int> bytes) → Map<String, dynamic> - Deserialize metadata from CBOR bytes
-
deserializeState(
List< int> bytes, String stateType) → dynamic - Deserialize a state object from CBOR bytes
-
getSerializedSize(
List< int> bytes) → int - Get the size of serialized data in bytes
-
serializeEvent(
Event event) → List< int> - Serialize an event to CBOR bytes
-
serializeMetadata(
Map< String, dynamic> metadata) → List<int> - Serialize metadata map to CBOR bytes
-
serializeState(
dynamic state) → List< int> - Serialize a state object to CBOR bytes