EventResult<TState extends State> class
Result of event application
Constructors
- EventResult.error(TState state, Event event, dynamic exception)
-
Create an error event result
factory
-
EventResult.failure(TState state, Event event, List<
String> errors) -
Create a failed event result
factory
- EventResult.success(TState oldState, TState newState, Event event)
-
Create a successful event result
factory
Properties
-
errors
→ List<
String> -
final
- event → Event
-
final
- exception → dynamic
-
final
- hasException → bool
-
Whether the event application had an exception
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFailure → bool
-
Whether the event application failed
no setter
- isSuccess → bool
-
final
- newState → TState
-
final
- oldState → TState
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateChanged → bool
-
Whether the state changed
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited